@@ -22,7 +22,6 @@ import os
 import re
 import pickle
 import shutil
-import warnings
 
 from bluegraph.exceptions import BlueGraphException, BlueGraphWarning
 from .similarity import SimilarityProcessor
@@ -93,45 +92,6 @@ class ElementClassifier(ABC):
         return self.model.predict(data)
 
 
-
-class Preprocessor(ABC):
-    """Preprocessor inferface for EmbeddingPipeline."""
-
-    @abstractmethod
-    def info(self):
-        """Get dictionary with the info."""
-        pass
-
-    @abstractmethod
-    def fit(self, data, **kwargs):
-        """Fit the preprocessor."""
-        pass
-
-    @abstractmethod
-    def transform(self, data, **kwargs):
-        """Tranform the input data."""
-        pass
-
-
-class Embedder(ABC):
-    """Embedder inferface for EmbeddingPipeline."""
-
-    @abstractmethod
-    def info(self):
-        """Get dictionary with the info."""
-        pass
-
-    @abstractmethod
-    def fit_model(self, data, **kwargs):
-        """Train specified model on the provided data."""
-        pass
-
-    @abstractmethod
-    def predict_embeddings(self, data=None, **kwargs):
-        """Predict embeddings of out-sample elements."""
-        pass
-
-
 class EmbeddingPipeline(object):
     """Data structure for stacking embedding pipelines.
 
@@ -245,21 +205,10 @@ class EmbeddingPipeline(object):
         """Get index of existing points."""
         return self.similarity_processor.index
 
-    def generate_embedding_table(self):
-        """Generate embedding table from similarity index."""
-        index = self.similarity_processor.index
-        pairs = [
-            (ind, self.similarity_processor._model.reconstruct(i))
-            for i, ind in enumerate(index)
-        ]
-        return pd.DataFrame(
-            pairs, columns=["@id", "embedding"]).set_index("@id")
-
-
     def retrieve_embeddings(self, indices):
         """Get embedding vectors for the input indices."""
         if self.similarity_processor is None:
-            raise EmbeddingPipelineException(
+            raise EmbeddingPipeline.EmbeddingPipelineException(
                 "Similarity processor object is None, cannot "
                 "retrieve embedding vectors")
         else:
