@@ -15,7 +15,8 @@
 #    limitations under the License.
 
 """Embedding service configs."""
-FORGE_CONFIG = "configs/forge_configs/prod-forge-nexus.yml"
+FORGE_CONFIG = "configs/forge_configs/forge-config.yml"
 DOWNLOAD_DIR = "downloads/"
+LOCAL = True
 
 DEBUG = True
